import 'dart:convert';
import 'dart:io';
import 'package:http/http.dart' as http;
import 'package:path/path.dart';

import 'introspection.dart';

Future<Map<String, dynamic>> fetchMetadata(String endpoint,
    {bool cache = false}) async {
  if (cache) {
    final tmpFilePath =
        Uri.parse(join(Directory.systemTemp.path, 'gqlmeta.json'));
    final fs = File.fromUri(tmpFilePath);
    final existed = fs.existsSync();
    if (existed) {
      final content = await fs.readAsString();
      return jsonDecode(content);
    }
  }
  final response = await http.post(endpoint,
      body: jsonEncode({
        'query': introspection,
      }),
      headers: {
        'content-type': 'application/json',
      });
  final List<dynamic> types =
      jsonDecode(response.body)['data']['__schema']['types'];
  final Map<String, dynamic> typeMap = {};
  for (var t in types) {
    typeMap[t['name']] = t;
  }
  return typeMap;
}
